from ngSkinTools2 import api, signal
from ngSkinTools2.observableValue import ObservableValue
from ngSkinTools2.python_compatibility import Object
from ngSkinTools2.ui.session import Session


def __create_tool_action__(parent, session, action_name, action_tooltip, exec_handler):
    """
    :type session: Session
    """

    from ngSkinTools2.ui import actions

    def execute():
        if not session.active() or session.state.currentLayer.layer is None:
            return

        exec_handler()

    result = actions.define_action(parent, action_name, callback=execute)
    result.setToolTip(action_tooltip)

    @signal.on(session.events.targetChanged)
    def update_state():
        result.setEnabled(session.state.layersAvailable and session.state.currentLayer.layer is not None)

    return result


def create_action__from_closest_joint(parent, session):
    def exec_handler():
        api.assign_from_closest_joint(session.state.selectedSkinCluster, session.state.currentLayer.layer, session.context.selectedInfluences())

    return __create_tool_action__(
        parent, session,
        action_name=u"Assign From Closest Joint",
        action_tooltip="For selected influences, assign 1.0 weight for closest influence per each vertex in selected layer",
        exec_handler=exec_handler)


class UnifyWeightsOptions(Object):
    overall_effect = ObservableValue(1.0)
    single_cluster_mode = ObservableValue(False)


def create_action__unify_weights(parent, session):
    options = UnifyWeightsOptions()

    def exec_handler():
        api.unify_weights(
            session.state.selectedSkinCluster, session.state.currentLayer.layer,
            overall_effect=options.overall_effect(),
            single_cluster_mode=options.single_cluster_mode())

    return __create_tool_action__(
        parent, session,
        action_name=u"Unify Weights",
        action_tooltip="For selected vertices, make verts the same for all verts",
        exec_handler=exec_handler
    ), options
