from PySide2 import QtWidgets, QtGui
from xml.sax.saxutils import escape as escape
from PySide2.QtCore import Qt
import os

from ngSkinTools2 import cleanup, version
from ngSkinTools2.licenseClient import licenseClient
from ngSkinTools2.ui import qt


def show(parent):
    """
    :type parent: QWidget
    """

    def header():
        # noinspection PyShadowingNames
        def leftSide():
            layout = QtWidgets.QVBoxLayout()
            layout.addStretch()
            layout.addWidget(QtWidgets.QLabel("<h1>ngSkinTools</h1>"))
            layout.addWidget(QtWidgets.QLabel("Version {0}".format(version.pluginVersion())))
            layout.addWidget(QtWidgets.QLabel(version.COPYRIGHT))

            url = QtWidgets.QLabel(
                '<a href="{0}" style="color: #007bff;">{0}</a>'.format(version.PRODUCT_URL))
            url.setTextInteractionFlags(Qt.TextBrowserInteraction)
            url.setOpenExternalLinks(True)
            layout.addWidget(url)
            layout.addStretch()
            return layout

        def logo():
            img = QtGui.QPixmap(os.path.join(os.path.dirname(__file__), "images", "logo.png"))
            imgLabel = QtWidgets.QLabel()
            imgLabel.setPixmap(img)
            imgLabel.setFixedSize(121, 120)
            layout.addWidget(imgLabel)
            return imgLabel

        result = QtWidgets.QWidget()
        result.setPalette(qt.alternative_palette_light())
        result.setAutoFillBackground(True)

        hSplit = QtWidgets.QHBoxLayout()
        hSplit.setMargin(30)
        result.setLayout(hSplit)

        hSplit.addLayout(leftSide())
        hSplit.addStretch()
        hSplit.addWidget(logo())

        return result

    # noinspection PyShadowingNames
    def body():
        result = QtWidgets.QWidget()
        layout = QtWidgets.QVBoxLayout()
        result.setLayout(layout)
        layout.setMargin(30)

        status = licenseClient.current_status()
        if status.licensed_to!="":
            layout.addWidget(QtWidgets.QLabel("This product is licensed to:"))
            layout.addWidget(QtWidgets.QLabel("<strong>" + escape(status.licensed_to) + "</strong>"))
        return result

    # noinspection PyShadowingNames
    def buttonsRow(window):
        layout = QtWidgets.QHBoxLayout()
        layout.addStretch()
        btnClose = QtWidgets.QPushButton("Close")
        btnClose.setMinimumWidth(100)
        layout.addWidget(btnClose)
        layout.setContentsMargins(20, 15, 20, 15)

        btnClose.clicked.connect(lambda: window.close())
        return layout

    window = QtWidgets.QWidget(parent,
                               Qt.Window | Qt.WindowTitleHint | Qt.CustomizeWindowHint)
    window.resize(600, 500)
    window.setAttribute(Qt.WA_DeleteOnClose)
    window.setWindowTitle("About ngSkinTools")
    layout = QtWidgets.QVBoxLayout()
    window.setLayout(layout)
    layout.setMargin(0)

    layout.addWidget(header())
    layout.addWidget(body())
    layout.addStretch(2)
    layout.addLayout(buttonsRow(window))

    window.show()

    cleanup.registerCleanupHandler(window.close)



