from ngSkinTools2.operations.layers import build_action_initialize_layers
from ngSkinTools2.operations.website_links import WebsiteLinksActions
from ngSkinTools2.python_compatibility import Object
from PySide2 import QtWidgets, QtGui, QtCore
from ngSkinTools2.operations import import_export_actions, import_v1_actions
from ngSkinTools2.ui.session import Session
from ngSkinTools2.api import PasteOperation
from ngSkinTools2.ui.updatewindow import build_action_check_for_updates


def define_action(parent, label, callback=None, icon=None, shortcut=None):
    result = QtWidgets.QAction(label, parent)
    if icon is not None:
        result.setIcon(QtGui.QIcon(icon))
    if callback is not None:
        result.triggered.connect(callback)
    if shortcut is not None:
        if not isinstance(shortcut, QtGui.QKeySequence):
            shortcut = QtGui.QKeySequence(shortcut)
        result.setShortcut(shortcut)

    return result


class Actions(Object):
    def __init__(self, parent, session):
        """
        :type session: Session
        """
        from ngSkinTools2.operations import layers, tools, removeLayerData
        from ngSkinTools2.ui.transferDialog import build_transfer_action

        self.separator = QtWidgets.QAction(parent)
        self.separator.setSeparator(True)

        self.initialize = build_action_initialize_layers(session, parent)
        self.exportFile = import_export_actions.buildAction_export(session, parent)
        self.importFile = import_export_actions.buildAction_import(session, parent)
        self.import_v1 = import_v1_actions.build_action_import_v1(session, parent)

        self.addLayer = layers.buildAction_createLayer(session, parent)
        self.deleteLayer = layers.buildAction_deleteLayer(session, parent)
        self.toggleLayerEnabled = layers.buildAction_toggleEnabled(session, parent)

        # self.moveLayerUp = defineCallbackAction(u"Move Layer Up", None, icon=":/moveLayerUp.png")
        # self.moveLayerDown = defineCallbackAction(u"Move Layer Down", None, icon=":/moveLayerDown.png")
        self.paint = define_action(parent, u"Paint", icon=":/paintSkinWeights.png")

        self.toolsAssignFromClosestJoint = tools.create_action__from_closest_joint(parent, session)
        self.toolsUnifyWeights, self.toolsUnifyWeightsOptions = tools.create_action__unify_weights(parent, session)

        self.toolsDeleteCustomNodes = define_action(
            parent, "Delete All Custom Nodes", callback=lambda: removeLayerData.removeCustomNodes(interactive=True, session=session))

        self.toolsDeleteCustomNodesOnSelection = define_action(
            parent, "Delete Custom Nodes For Selection",
            callback=lambda: removeLayerData.removeCustomNodesFromSelection(interactive=True, session=session))

        self.transfer = build_transfer_action(session=session, parent=parent)

        # self.setLayerMirrored = defineAction(u"Mirrored", icon=":/polyMirrorGeometry.png")
        # self.setLayerMirrored.setCheckable(True)

        self.documentation = WebsiteLinksActions(parent=parent)

        self.check_for_updates = build_action_check_for_updates(parent=parent)

        from ngSkinTools2.operations import copy_paste_actions
        self.cut_influences = copy_paste_actions.action_copy_cut(session, parent, True)
        self.copy_influences = copy_paste_actions.action_copy_cut(session, parent, False)
        self.paste_weights = copy_paste_actions.action_paste(session, parent, PasteOperation.replace)
        self.paste_weights_add = copy_paste_actions.action_paste(session, parent, PasteOperation.add)
        self.paste_weights_sub = copy_paste_actions.action_paste(session, parent, PasteOperation.subtract)

    def addLayersActions(self, context):
        context.addAction(self.addLayer)
        context.addAction(self.deleteLayer)
        context.addAction(self.separator)
        context.addAction(self.toggleLayerEnabled)
        # context.addAction(self.moveLayerUp)
        # context.addAction(self.moveLayerDown)
        # context.addAction(self.separator)
        # context.addAction(self.setLayerMirrored)

    def addInfluencesActions(self, context):
        context.addAction(self.toolsAssignFromClosestJoint)
        context.addAction(self.separator)
        context.addAction(self.cut_influences)
        context.addAction(self.copy_influences)
        context.addAction(self.paste_weights)
        context.addAction(self.paste_weights_add)
        context.addAction(self.paste_weights_sub)
