from PySide2 import QtWidgets
from ngSkinTools2 import signal
from ngSkinTools2.operations import tools
from ngSkinTools2.ui import qt, widgets, model_binds
from ngSkinTools2.ui.actions import Actions
from ngSkinTools2.ui.layout import TabSetup, createTitledRow
from ngSkinTools2.ui.session import Session


def buildUI(parentWindow, actions, session):
    """

    :type actions: Actions
    :type session: Session
    """

    def assignWeightsFromClosestJointGroup():
        result = QtWidgets.QGroupBox("Assign weights from closest joint")
        layout = QtWidgets.QVBoxLayout()
        result.setLayout(layout)

        btn = QtWidgets.QPushButton()
        qt.bind_action_to_button(actions.toolsAssignFromClosestJoint, btn)
        layout.addWidget(btn)

        return result

    def unifyWeightsGroup():
        result = QtWidgets.QGroupBox("Unify weights")
        layout = QtWidgets.QVBoxLayout()
        result.setLayout(layout)

        options = actions.toolsUnifyWeightsOptions

        intensity = widgets.NumberSliderGroup()
        model_binds.bind(intensity, options.overall_effect)

        single_cluster_mode = QtWidgets.QCheckBox("Single group mode", )
        single_cluster_mode.setToolTip("average weights across whole selection, ignoring separate shells or selection gaps")
        model_binds.bind(single_cluster_mode, options.single_cluster_mode)

        btn = QtWidgets.QPushButton()
        qt.bind_action_to_button(actions.toolsUnifyWeights, btn)

        layout.addLayout(createTitledRow("Intensity:", intensity.layout()))
        layout.addLayout(createTitledRow("Clustering:", single_cluster_mode))
        layout.addWidget(btn)

        return result

    tab = TabSetup()
    tab.innerLayout.addWidget(assignWeightsFromClosestJointGroup())
    tab.innerLayout.addWidget(unifyWeightsGroup())
    tab.innerLayout.addStretch()

    @signal.on(session.events.targetChanged, qtParent=tab.tabContents)
    def updateTabEnabled():
        tab.tabContents.setEnabled(session.state.layersAvailable)

    updateTabEnabled()

    return tab.tabContents
