from ngSkinTools2.python_compatibility import Object
from PySide2 import QtWidgets, QtCore
from ngSkinTools2.signal import Signal
from ngSkinTools2.ui import qt


class NumberSliderGroup(Object):
    """
    float spinner is the "main control" while the slider acts as complementary way to change value
    """

    def __init__(self, type=float, minimum=0, maximum=1, tooltip=""):
        isFloatSpinner = type==float

        self.__layout = layout = QtWidgets.QHBoxLayout()
        self.valueChanged = Signal("sliderGroupValueChanged")

        sliderResolution = 1000.0

        self.spinner = spinner = QtWidgets.QDoubleSpinBox() if isFloatSpinner else QtWidgets.QSpinBox()

        spinner.setMinimumWidth(80)
        if isFloatSpinner:
            spinner.setDecimals(2)

        singleStep = (maximum - minimum) / 100.0
        if not isFloatSpinner and singleStep<1:
            singleStep = 1
        spinner.setSingleStep(singleStep)

        spinner.setToolTip(tooltip)

        self.slider = slider = QtWidgets.QSlider(QtCore.Qt.Horizontal)
        slider.setMinimum(minimum)
        slider.setMaximum((maximum-minimum) * sliderResolution)
        slider.setToolTip(tooltip)

        layout.addWidget(spinner)
        layout.addWidget(slider)

        def valueChanged():
            with qt.signalsBlocked(slider):
                slider.setValue((spinner.value()-minimum) * sliderResolution)
            self.valueChanged.emit()

        def sliderUpdated():
            spinner.setValue(minimum+slider.value() / sliderResolution)

        spinner.valueChanged.connect(valueChanged)
        slider.valueChanged.connect(sliderUpdated)

    def layout(self):
        return self.__layout

    def value(self):
        return self.spinner.value()

    def setValue(self, value):
        self.spinner.setValue(value)

    def setEnabled(self, enabled):
        self.spinner.setEnabled(enabled)
        self.slider.setEnabled(enabled)



def buttonRow(buttonDefs):
    result = QtWidgets.QHBoxLayout()

    result.addStretch()
    for label, handler in buttonDefs:
        btn = QtWidgets.QPushButton(label, minimumWidth=100)
        qt.on(btn.clicked)(handler)
        result.addWidget(btn)

    return result
